@@ -276,7 +276,9 @@ class AutoCrosswalk(object):
                 key_to = P.columns.get_level_values(level=key).tolist()
             
                 for k in key_from:
-                    P_temp[P_temp.index.get_level_values(key) == k] = self.numericmatcher.compute_similarity(a=k, b=key_to)
+                    P_temp[P_temp.index.get_level_values(key) == k] = self.numericmatcher.compute_similarity(a=k,
+                                                                                                             b=key_to,
+                                                                                                             remove_special_characters=True)
                  
                 # Sanity check
                 if ((P_temp>1).any() | (P_temp<0).any()).any():
@@ -309,7 +311,9 @@ class AutoCrosswalk(object):
                 key_to = P.columns.get_level_values(level=key).tolist()
             
                 for k in key_from:
-                    P_temp[P_temp.index.get_level_values(key) == k] = self.textmatcher.compute_similarity(a=k, b=key_to)
+                    P_temp[P_temp.index.get_level_values(key) == k] = self.textmatcher.compute_similarity(a=k,
+                                                                                                          b=key_to,
+                                                                                                          use_lower_characters=True)
                  
                 # Sanity check
                 if ((P_temp>1).any() | (P_temp<0).any()).any():
@@ -550,11 +554,17 @@ class AutoCrosswalk(object):
         # Subset temporaty
         temp = temp.loc[~mask_empty]
         
-        # Turn series of dataframes into dataframe by concatenating
-        exact = pd.concat(objs=temp.tolist())
-
-        # Fix index
-        exact.index = temp.index
+        if temp.tolist():
+        
+            # Turn series of dataframes into dataframe by concatenating
+            exact = pd.concat(objs=temp.tolist())
+    
+            # Fix index
+            exact.index = temp.index
+            
+        else:
+            exact = pd.DataFrame()
+        
 
         return exact
 
@@ -678,6 +688,7 @@ class AutoCrosswalk(object):
                            context_key=None,
                            weights=None,
                            use_existing_transition_matrix=True,
+                           which_priority="numeric",
                            prefix="NEW "):
         """
         Prepare proper crosswalk file
@@ -700,6 +711,28 @@ class AutoCrosswalk(object):
                                       numeric_key=numeric_key,
                                       text_key=text_key,
                                       context_key=context_key)
+
+        # Fix priority        
+        if not numeric_key:
+            if which_priority=="numeric":
+                if text_key:
+                    which_priority = "text"
+                else:
+                    which_priority = "context"
+
+        if not text_key:
+            if which_priority=="text":
+                if numeric_key:
+                    which_priority = "numeric"
+                else:
+                    which_priority = "context"
+
+        if not context_key:
+            if which_priority=="context":
+                if numeric_key:
+                    which_priority = "numeric"
+                else:
+                    which_priority = "text"
         # ---------------------------------------------------------------------
         # Estimate transition proabability matrix
         # ---------------------------------------------------------------------
@@ -724,7 +757,8 @@ class AutoCrosswalk(object):
                 
         if self.prioritize_exact_match:
             # Find exact matches
-            crosswalk_exact = self._find_exact_match(transition_matrix=transition_matrix)
+            crosswalk_exact = self._find_exact_match(transition_matrix=transition_matrix,
+                                                     which_priority=which_priority)
             
             # Update existing crosswalk
             crosswalk.update(other=crosswalk_exact)
@@ -755,7 +789,8 @@ class AutoCrosswalk(object):
                                                    context_key=context_key)
                 
             # Find exact matches
-            crosswalk_exact_to = self._find_exact_match(transition_matrix=transition_matrix_to)
+            crosswalk_exact_to = self._find_exact_match(transition_matrix=transition_matrix_to,
+                                                        which_priority=which_priority)
             
             # Update existing crosswalk
             crosswalk_to.update(other=crosswalk_exact_to)
