@@ -3,7 +3,7 @@
 #------------------------------------------------------------------------------
 # Standard
 import bodyguard as bg
-
+import re
 #------------------------------------------------------------------------------
 # Main
 #------------------------------------------------------------------------------
@@ -63,7 +63,7 @@ class NumericMatcher(object):
     # -------------------------------------------------------------------------
     # Public functions
     # -------------------------------------------------------------------------
-    def compute_similarity(self,a,b):
+    def compute_similarity(self,a,b,remove_special_characters=True):
         """
         Compute similarity between string and each element in list
         """
@@ -71,6 +71,10 @@ class NumericMatcher(object):
         self._check_a(a=a)
         self._check_b(b=b)
         
+        if remove_special_characters:
+            a = re.sub('\W+','', a)
+            b = [re.sub('\W+','', x) for x in b]
+            
         # Compute similarities for all elements in b
         similarities = [self._compare_codes(a=a,b=x) for x in b]
             
