@@ -75,7 +75,7 @@ class TextMatcher(object):
     # -------------------------------------------------------------------------
     # Public functions
     # -------------------------------------------------------------------------
-    def compute_similarity(self,a,b,**kwargs):
+    def compute_similarity(self,a,b,use_lower_characters=True,**kwargs):
         """
         Compute similarity between string and each element in list
         """
@@ -83,6 +83,10 @@ class TextMatcher(object):
         self._check_a(a=a)
         self._check_b(b=b)
         
+        if use_lower_characters:
+            a = a.lower()
+            b = [x.lower() for x in b]
+            
         if self.method=="Ratcliff-Obershelp":
             similarities = [self._ratcliff_obershelp(a=a,
                                                      b=x,
